@@ -40,6 +40,8 @@
 
 #include <glibmm/i18n.h>
 
+#include <iostream>
+
 
 #ifndef G_OS_WIN32
 static EpcProtocol publish_protocol = EPC_PROTOCOL_HTTPS;
@@ -512,7 +514,7 @@ const FieldTypes* ConnectionPool::get_field_types() const
   return m_pFieldTypes;
 }
 
-Glib::ustring ConnectionPool::get_string_find_operator() const
+Gnome::Gda::SqlOperatorType ConnectionPool::get_string_find_operator() const
 {
   g_assert(m_backend.get());
   return m_backend->get_string_find_operator();
@@ -567,7 +569,7 @@ bool ConnectionPool::handle_error_cerr_only()
   {
     Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
 
-    typedef std::list< Glib::RefPtr<Gnome::Gda::ConnectionEvent> > type_list_errors;
+    typedef std::vector< Glib::RefPtr<Gnome::Gda::ConnectionEvent> > type_list_errors;
     type_list_errors list_errors = gda_connection->get_events();
 
     if(!list_errors.empty())
