@@ -16,10 +16,10 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <config.h>
+#include "config.h"
 #include <libglom/document/bakery/document.h>
 #include <giomm.h>
-//#include <fstream>
+#include <iostream>
 #include <glibmm/i18n-lib.h>
 
 namespace GlomBakery
