@@ -616,20 +616,47 @@ Glib::ustring Utils::string_escape_underscores(const Glib::ustring& text)
 Glib::ustring Utils::locale_simplify(const Glib::ustring& locale_id)
 {
   Glib::ustring result = locale_id;
+  
+  //At least Ubuntu Natty provides a long string such as this: LC_CTYPE=en_US.UTF-8;LC_NUMERIC=en_US.UTF-8;LC_TIME=en_US.UTF-8;LC_COLLATE=en_US.UTF-8;LC_MONETARY=en_US.UTF-8;LC_MESSAGES=en_AG.utf8;LC_PAPER=en_US.UTF-8;LC_NAME=en_US.UTF-8;LC_ADDRESS=en_US.UTF-8;LC_TELEPHONE=en_US.UTF-8;LC_MEASUREMENT=en_US.UTF-8;LC_IDENTIFICATION=en_US.UTF-8
+  //In Ubuntu Maverick, and earlier, it was apparently a simple string such as en_US.UTF-8.
 
+  //Look for LC_ALL or LC_COLLATE
+  //(We use the locale name only to identify translations
+  //Otherwise just start with the whole string.
+  Glib::ustring::size_type posCategory = result.find("LC_ALL=");
+  if(posCategory != Glib::ustring::npos)
+  {
+    result = result.substr(posCategory);
+  }
+  else
+  {
+    posCategory = result.find("LC_COLLATE=");
+    if(posCategory != Glib::ustring::npos)
+    {
+      result = result.substr(posCategory);
+    }
+  }
+  
   //Get everything before the .:
-  Glib::ustring::size_type posDot = locale_id.find('.');
+  const Glib::ustring::size_type posDot = result.find('.');
   if(posDot != Glib::ustring::npos)
   {
     result = result.substr(0, posDot);
   }
 
   //Get everything before the @:
-  const Glib::ustring::size_type posAt = locale_id.find('@');
+  const Glib::ustring::size_type posAt = result.find('@');
   if(posAt != Glib::ustring::npos)
   {
     result = result.substr(0, posAt);
   }
+  
+  //Get everything after the =, if any:
+  const Glib::ustring::size_type posEquals = result.find('=');
+  if(posEquals != Glib::ustring::npos)
+  {
+    result = result.substr(posEquals + 1);
+  }
 
   return result;
 }
@@ -655,7 +682,7 @@ Glib::ustring Utils::create_local_image_uri(const Gnome::Gda::Value& value)
 
   if(value.get_value_type() == GDA_TYPE_BINARY)
   {
-    glong size = 0;
+    long size = 0;
     gconstpointer pData = value.get_binary(size);
     if(size && pData)
     {
@@ -1000,6 +1027,10 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_target(table_name);
 
+  //We need to add some fields to select,
+  //because otherwise the SqlBuilder would not contain a valid query.
+  builder->select_add_field("*", table_name);
+
   if(!document)
   {
     std::cerr << G_STRFUNC << ": document was null." << std::endl;
@@ -1009,7 +1040,7 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
   //TODO: Cache the list of all fields, as well as caching (m_Fields) the list of all visible fields:
   const Document::type_vec_fields fields = document->get_table_fields(table_name);
 
-  guint previous_and_id = 0;
+  guint previous_id = 0;
   typedef std::vector< sharedptr<LayoutItem_Field> > type_vecLayoutFields;
   type_vecLayoutFields fieldsToGet;
   for(Document::type_vec_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
@@ -1026,28 +1057,31 @@ Gnome::Gda::SqlExpr Utils::get_find_where_clause_quick(const Document* document,
 
     if(use_this_field)
     {
-      const guint eq_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ, //TODO: Ue field->sql_find_operator().
+      //std::cout << "Using field: " << field->get_name() << std::endl;
+      const guint eq_id = builder->add_cond(field->sql_find_operator(),
         builder->add_field_id(field->get_name(), table_name),
-        builder->add_expr(quick_search)); //Use  field->sql_find(quick_search);
+        builder->add_expr( field->sql_find(quick_search) )); //sql_find() modifies the value for the operator.
 
-      guint and_id = 0;
-      if(previous_and_id)
+      if(previous_id)
       {
-        and_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_AND,
-        previous_and_id, eq_id);
+        const guint or_id = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_OR,
+          previous_id, eq_id);
+        previous_id = or_id;
       }
-
-      previous_and_id = and_id;
+      else
+        previous_id = eq_id;
     }
   }
 
-  if(previous_and_id)
+  if(previous_id)
   {
-    builder->set_where(previous_and_id); //This might be unnecessary.
-    return builder->export_expression(previous_and_id);
+    builder->set_where(previous_id); //This might be unnecessary.
+    //std::cout << G_STRFUNC << ": builder: " << sqlbuilder_get_full_query(builder) << std::endl; 
+    return builder->export_expression(previous_id);
   }
   else
   {
+    std::cerr << G_STRFUNC << ": Returning null SqlExpr" << std::endl;
     return Gnome::Gda::SqlExpr();
   }
 }
